@@ -9,7 +9,8 @@ from transformers import (PreTrainedTokenizerBase,
                           AutoConfig,
                           TrainingArguments,
                           Trainer,
-                          PrinterCallback)
+                          PrinterCallback,
+                          EarlyStoppingCallback)
 from typing import Dict, Optional, Tuple, List, Any
 import numpy as np
 import requests
@@ -350,8 +351,16 @@ class BaseBenchmark(ABC):
                                           len(old_model_id2label))
 
                         # Load the weights from the model's current
-                        # classification layer
-                        clf_weight = model.classifier.weight.data
+                        # classification layer. This handles both the token
+                        # classification case and the sequence classification
+                        # case.
+                        # NOTE: This might need additional cases (or a general
+                        #       solution) when we start dealing with other
+                        #       tasks.
+                        try:
+                            clf_weight = model.classifier.weight.data
+                        except AttributeError:
+                            clf_weight = model.classifier.out_proj.weight.data
 
                         # Create the new weights, which have zeros at all the
                         # new entries
@@ -709,6 +718,10 @@ class BaseBenchmark(ABC):
                             id2label=model.config.id2label
                         )
 
+                        # Initialise early stopping callback
+                        params = dict(early_stopping_patience=2)
+                        early_stopping = EarlyStoppingCallback(**params)
+
                         # Initialise Trainer
                         split = trains[idx].train_test_split(0.1, seed=4242)
                         trainer_args = dict(model=model,
@@ -717,7 +730,8 @@ class BaseBenchmark(ABC):
                                             eval_dataset=split['test'],
                                             tokenizer=tokenizer,
                                             data_collator=data_collator,
-                                            compute_metrics=compute_metrics)
+                                            compute_metrics=compute_metrics,
+                                            callbacks=[early_stopping])
                         if self.multilabel:
                             trainer_args['split_point'] = self.split_point
                             trainer = TwolabelTrainer(**trainer_args)
